@@ -3,11 +3,12 @@
 import collections.abc
 import unittest
 
-from system_intelligence.gpu_info import query_gpus
+from system_intelligence.gpus_info import GpusInfo
 
 
 class Tests(unittest.TestCase):
 
     def test_query_gpus(self):
-        info = query_gpus()
+        gpu_info = GpusInfo()
+        info = gpu_info.query_gpus()
         self.assertIsInstance(info, collections.abc.Sequence)
